"use client";
import React, { useState, useEffect } from "react";
import PageHeader from "../components/page-header";
import { Card, CardContent } from "@/components/ui/card";
import { Button } from "@/components/ui/button";
import { Heart } from "lucide-react";
import Image from "next/image";
import Cookies from "js-cookie";
import axios from "axios";

// Skeleton Loader Component
const SkeletonLoader = () => (
  <Card className="flex items-center p-4 gap-4 animate-pulse">
    <div className="w-6 h-6 bg-gray-200 rounded-full" />
    <div className="w-24 h-24 md:w-32 md:h-32 bg-gray-200 rounded" />
    <div className="flex-1 flex flex-col md:flex-row gap-2 justify-between">
      <div className="w-full">
        <div className="h-5 bg-gray-200 rounded w-3/4 mb-2" />
        <div className="h-4 bg-gray-200 rounded w-1/2" />
      </div>
      <div className="flex gap-4 md:gap-6 items-center w-full md:w-auto justify-between">
        <div className="h-5 bg-gray-200 rounded w-16" />
        <div className="h-10 bg-gray-200 rounded w-24" />
      </div>
    </div>
  </Card>
);

// WishlistButton Component
const WishlistButton = ({ item, onToggle }) => {
  const [isActive, setIsActive] = useState(true); // Initially true for wishlist items
  const token = Cookies.get("access_token");

  const handleWishList = async (product_id) => {
    const previousState = isActive;
    setIsActive(!isActive); // Optimistic update

    try {
      const orderData = { product_id };
      const response = await axios.post(
        `${process.env.NEXT_PUBLIC_BASE_URL}toggleWishlist`,
        orderData,
        {
          headers: {
            Authorization: `Bearer ${token}`,
            "Content-Type": "application/json",
          },
        }
      );

      if (response.status === 200) {
        onToggle(product_id, !isActive); // Notify parent
      } else {
        setIsActive(previousState); // Revert on failure
      }
    } catch (error) {
      console.error("Error toggling wishlist:", error);
      setIsActive(previousState); // Revert on error
    }
  };

  if (!token) {
    return <Heart size={18} className="text-gray-300 cursor-not-allowed" />;
  }

  return (
    <Heart
      onClick={() => handleWishList(item.product_id)}
      size={18}
      className={`cursor-pointer ${isActive ? "text-red-500 fill-current" : "text-gray-500"}`}
      fill={isActive ? "currentColor" : "none"}
    />
  );
};

export default function Wishlist() {
  const [wishlistItems, setWishlistItems] = useState([]);
  const [isLoading, setIsLoading] = useState(true); // Track loading state
  const token = Cookies.get("access_token");

  // Fetch wishlist on mount
  useEffect(() => {
    const fetchWishlist = async () => {
      setIsLoading(true);
      try {
        const response = await axios.get(
          `${process.env.NEXT_PUBLIC_BASE_URL}getWishlist`,
          {
            headers: {
              Authorization: `Bearer ${token}`,
              "Content-Type": "application/json",
            },
          }
        );
        if (response.data.success) {
          setWishlistItems(response.data.wishlist);
        } else {
          setWishlistItems([]);
        }
      } catch (error) {
        console.error("Error fetching wishlist:", error);
        setWishlistItems([]);
      } finally {
        setIsLoading(false);
      }
    };
    if (token) {
      fetchWishlist();
    } else {
      setIsLoading(false);
    }
  }, [token]);

  // Handle wishlist toggle (add/remove)
  const handleToggleWishlist = (product_id, isAdded) => {
    if (!isAdded) {
      setWishlistItems((prev) =>
        prev.filter((item) => item.product_id !== product_id)
      );
    }
  };

  return (
    <>
      <PageHeader title="Wishlist" breadcrumb="Home - WishList" />

      <div className="flex flex-col items-center mx-4 md:mx-6 lg:mx-auto max-w-6xl mt-6 gap-4 px-2 sm:px-4">
        <div className="w-full space-y-4">
          {isLoading ? (
            // Show skeleton loaders
            <>
              <SkeletonLoader />
              <SkeletonLoader />
            </>
          ) : wishlistItems.length === 0 ? (
            <p className="text-center text-gray-500">Your wishlist is empty.</p>
          ) : (
            wishlistItems.map((item, index) => (
              <Card
                key={index}
                className="relative flex flex-col sm:flex-row items-start sm:items-center p-4 gap-4 w-full"
              >
                <div className="absolute top-2 right-2 sm:static sm:flex sm:items-center">
                  <WishlistButton
                    item={item}
                    onToggle={handleToggleWishlist}
                  />
                </div>
                <Image
                  src={
                    item.product.product_images.startsWith("http")
                      ? item.product.product_images
                      : `${process.env.NEXT_PUBLIC_IMAGE_URL}/${item.product.product_images}`
                  }
                  alt={item.product.product_name}
                  width={300}
                  height={300}
                  className="rounded w-full h-48 sm:w-32 sm:h-32 object-cover"
                />
                <div className="flex-1 flex flex-col sm:flex-row gap-2 sm:gap-4 justify-between w-full pt-8 sm:pt-0">
                  <div className="w-full sm:w-2/3">
                    <h3 className="font-medium text-sm sm:text-base">
                      {item.product.product_name}
                    </h3>
                    <p className="text-xs sm:text-sm text-gray-600">
                      Category: {item.product.category_name}
                    </p>
                    <p className="font-semibold text-sm sm:text-base text-foreground sm:hidden">
                      Rs. {item.product.product_discounted_price.toFixed(2)}
                    </p>
                  </div>
                  <div className="flex flex-col sm:flex-row gap-2 sm:gap-4 items-center w-full sm:w-auto justify-between sm:justify-end">
                    <p className="font-semibold text-sm sm:text-base text-foreground hidden sm:block">
                      Rs. {item.product.product_discounted_price.toFixed(2)}
                    </p>
                    <Button size="sm" className="w-full sm:w-auto">
                      Add To Cart
                    </Button>
                  </div>
                </div>
              </Card>
            ))
          )}
        </div>
      </div>
    </>
  );
}